GetMallocHeapSizeForZone

Function GetMallocHeapSizeForZone 

pub unsafe extern "C" fn GetMallocHeapSizeForZone(
    zone: *mut Zone,
) -> usize
This function reports the size of all malloc memory referred to from this zone.

Note that malloc memory referred to from this zone can include SharedArrayBuffers which may also be referred to from other zones. Adding the memory usage of multiple zones may lead to an over-estimate.