pub unsafe extern "C" fn GetPromiseAllocationSite(
promise: Handle<*mut JSObject>,
) -> *mut JSObjectExpand description
Returns a js::SavedFrame linked list of the stack that lead to the given Promise’s allocation.
The promise parameter here should be an unwrapped promise.